==> qmmp-0.12.20.tar.bz2: qmmp-0.12.20/src/plugins/General/streambrowser/translations/streambrowser_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>EditStreamDialog</name>
    <message>
        <location filename="../editstreamdialog.ui" line="14"/>
        <source>Edit Stream</source>
        <translation>Edytuj strumień</translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="34"/>
        <source>URL:</source>
        <translation>Adres URL:</translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="44"/>
        <source>Name:</source>
        <translation>Nazwa:</translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="54"/>
        <source>Genre:</source>
        <translation>Gatunek:</translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="64"/>
        <source>Bitrate:</source>
        <translation>Przepływność:</translation>
    </message>
    <message>
        <location filename="../editstreamdialog.ui" line="74"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
</context>
<context>
    <name>StreamBrowser</name>
    <message>
        <location filename="../streambrowser.cpp" line="33"/>
        <source>Add Stream</source>
        <translation>Dodaj strumień</translation>
    </message>
    <message>
        <location filename="../streambrowser.cpp" line="35"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
</context>
<context>
    <name>StreamBrowserFactory</name>
    <message>
        <location filename="../streambrowserfactory.cpp" line="29"/>
        <source>Stream Browser Plugin</source>
        <translation>Wtyczka Przeglądarka strumieni</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="50"/>
        <source>About Stream Browser Plugin</source>
        <translation>O wtyczce Przeglądarka strumieni</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="51"/>
        <source>Qmmp Stream Browser Plugin</source>
        <translation>Wtyczka Przeglądarka strumieni dla Qmmp</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="52"/>
        <source>This plugin allows one to add stream from IceCast stream directory</source>
        <translation>Ta wtyczka pozwala dodawać strumienie z katalogu strumieni IceCast</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Napisana przez: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>StreamWindow</name>
    <message>
        <location filename="../streamwindow.ui" line="14"/>
        <source>Stream Browser</source>
        <translation>Przeglądarka strumieni</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="31"/>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="47"/>
        <source>Favorites</source>
        <translation>Ulubione</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="73"/>
        <source>IceCast</source>
        <translation>IceCast</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="102"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="109"/>
        <source>Update</source>
        <translation>Aktualizuj</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="55"/>
        <location filename="../streamwindow.cpp" line="73"/>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="56"/>
        <location filename="../streamwindow.cpp" line="74"/>
        <source>Genre</source>
        <translation>Gatunek</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="57"/>
        <location filename="../streamwindow.cpp" line="75"/>
        <source>Bitrate</source>
        <translation>Przepływność</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="58"/>
        <location filename="../streamwindow.cpp" line="76"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="131"/>
        <source>&amp;Add to favorites</source>
        <translation>&amp;Dodaj do ulubionych</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="134"/>
        <source>&amp;Add to playlist</source>
        <translation>&amp;Dodaj do listy odtwarzania</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="137"/>
        <source>&amp;Create</source>
        <translation>&amp;Utwórz</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="139"/>
        <source>&amp;Edit</source>
        <translation>&amp;Edycja</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="142"/>
        <source>&amp;Remove</source>
        <translation>&amp;Usuń</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="154"/>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="157"/>
        <location filename="../streamwindow.cpp" line="158"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="177"/>
        <source>Receiving</source>
        <translation>Pobieranie</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="274"/>
        <source>Edit Stream</source>
        <translation>Edytuj strumień</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/General/streambrowser/translations/streambrowser_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>StreamBrowser</name>
    <message>
        <location filename="../streambrowser.cpp" line="33"/>
        <source>Stream Browser</source>
        <translation>Przeglądarka strumieni</translation>
    </message>
    <message>
        <location filename="../streambrowser.cpp" line="35"/>
        <source>Ctrl+U</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StreamBrowserFactory</name>
    <message>
        <location filename="../streambrowserfactory.cpp" line="29"/>
        <source>Stream Browser Plugin</source>
        <translation>Wtyczka Przeglądarka strumieni</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="50"/>
        <source>About Stream Browser Plugin</source>
        <translation>O wtyczce Przeglądarka strumieni</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="51"/>
        <source>Qmmp Stream Browser Plugin</source>
        <translation>Wtyczka Qmmp Przeglądarka strumieni</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="52"/>
        <source>This plugin allows one to add stream from IceCast stream directory</source>
        <translation>Ta wtyczka pozwala dodawać strumienie z katalogu strumieni IceCast</translation>
    </message>
    <message>
        <location filename="../streambrowserfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StreamWindow</name>
    <message>
        <location filename="../streamwindow.ui" line="14"/>
        <source>Stream Browser</source>
        <translation>Przeglądarka strumieni</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="31"/>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="47"/>
        <source>Favorites</source>
        <translation>Ulubione</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="73"/>
        <source>IceCast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="102"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../streamwindow.ui" line="109"/>
        <source>Update</source>
        <translation>Aktualizuj</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="52"/>
        <location filename="../streamwindow.cpp" line="70"/>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="53"/>
        <location filename="../streamwindow.cpp" line="71"/>
        <source>Genre</source>
        <translation>Gatunek</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="54"/>
        <location filename="../streamwindow.cpp" line="72"/>
        <source>Bitrate</source>
        <translation>Przepływność</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="55"/>
        <location filename="../streamwindow.cpp" line="73"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="126"/>
        <source>&amp;Add to favorites</source>
        <translation>&amp;Dodaj do ulubionych</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="127"/>
        <source>&amp;Add to playlist</source>
        <translation>&amp;Dodaj do listy odtwarzania</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="132"/>
        <source>&amp;Remove</source>
        <translation>&amp;Usuń</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="142"/>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="145"/>
        <location filename="../streamwindow.cpp" line="146"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../streamwindow.cpp" line="165"/>
        <source>Receiving</source>
        <translation>Pobieranie</translation>
    </message>
</context>
</TS>
